P4 to Git Change 1537228 by skudchad@skudchad_test2_win_opencl on 2018/04/05 14:53:31

SWDEV-145570 - [HIP] -  Add HIP Memory, texture, surface, context api skeletons

	ReviewBoardURL = http://ocltc.amd.com/reviews/r/14565/diff/

Affected files ...

... //depot/stg/opencl/drivers/opencl/api/hip/hip_context.cpp#6 edit
... //depot/stg/opencl/drivers/opencl/api/hip/hip_device.cpp#9 edit
... //depot/stg/opencl/drivers/opencl/api/hip/hip_event.cpp#2 edit
... //depot/stg/opencl/drivers/opencl/api/hip/hip_memory.cpp#7 edit
... //depot/stg/opencl/drivers/opencl/api/hip/hip_stream.cpp#3 edit
... //depot/stg/opencl/drivers/opencl/api/hip/hip_surface.cpp#1 add
... //depot/stg/opencl/drivers/opencl/api/hip/hip_texture.cpp#1 add
This commit is contained in:
foreman
2018-04-05 15:02:43 -04:00
parent 0f8877096f
commit 6fc37f7147
7 changed files with 496 additions and 136 deletions
+24 -12
View File
@@ -24,44 +24,56 @@ THE SOFTWARE.
#include "hip_internal.hpp"
hipError_t hipEventCreateWithFlags(hipEvent_t* event, unsigned flags)
{
hipError_t hipEventCreateWithFlags(hipEvent_t* event, unsigned flags) {
HIP_INIT_API(event, flags);
assert(0 && "Unimplemented");
return hipErrorUnknown;
}
hipError_t hipEventCreate(hipEvent_t* event)
{
hipError_t hipEventCreate(hipEvent_t* event) {
HIP_INIT_API(event);
assert(0 && "Unimplemented");
return hipErrorUnknown;
}
hipError_t hipEventDestroy(hipEvent_t event)
{
hipError_t hipEventDestroy(hipEvent_t event) {
HIP_INIT_API(event);
assert(0 && "Unimplemented");
return hipErrorUnknown;
}
hipError_t hipEventElapsedTime(float *ms, hipEvent_t start, hipEvent_t stop)
{
hipError_t hipEventElapsedTime(float *ms, hipEvent_t start, hipEvent_t stop) {
HIP_INIT_API(ms, start, stop);
return hipErrorUnknown;
}
hipError_t hipEventRecord(hipEvent_t event, hipStream_t stream)
{
hipError_t hipEventRecord(hipEvent_t event, hipStream_t stream) {
HIP_INIT_API(event, stream);
assert(0 && "Unimplemented");
return hipErrorUnknown;
}
hipError_t hipEventSynchronize(hipEvent_t event)
{
hipError_t hipEventSynchronize(hipEvent_t event) {
HIP_INIT_API(event);
assert(0 && "Unimplemented");
return hipErrorUnknown;
}
hipError_t hipEventQuery(hipEvent_t event) {
HIP_INIT_API(event);
assert(0 && "Unimplemented");
return hipErrorUnknown;
}